==> js-api-creator-1.0.21.tgz: package/es/modules/community.js <==
import { constants } from '@zohodesk/js-api-creator';
export default {
  "communityCategory": {
    url: "communityCategory",
    method: constants.get
  },
  "communityCategory.follow": {
    url: "communityCategory/:id/follow",
    method: constants.post
  },
  "communityCategory.unfollow": {
    url: "communityCategory/:id/unfollow",
    method: constants.post
  },
  "communityCategory.followers": {
    url: "communityCategory/:id/followers",
    method: constants.get
  },
  "communityAddTopic": {
    url: "communityTopics",
    method: constants.post
  },
  "communityDraftTopic": {
    url: "communityTopics/saveDraft",
    method: constants.post
  },
  "communityUpdateDraft": {
    url: "communityTopics/:id/updateDraft",
    method: constants.put
  },
  "communityPublishDraft": {
    url: "communityTopics/:id/publishDraft",
    method: constants.post
  },
  "communityDeleteDraft": {
    url: "communityTopics/:id/deleteDraft",
    method: constants.deleteIt
  },
  "communityTopics": {
    url: "communityTopics",
    method: constants.get
  },
  "communityTopContributors": {
    url: "community/topContributors",
    method: constants.get
  },
  "communityModerationTopics": {
    url: "communityModeration/topics",
    method: constants.get
  },
  "communityModerationComments": {
    url: "communityModeration/comments",
    method: constants.get
  },
  "communityModerationStats": {
    url: "communityModeration/counts",
    method: constants.get
  },
  "communityModeratedTopics": {
    url: "communityModeratedTopics",
    method: constants.get
  },
  "communityApproveAllAwaitingTopics": {
    url: "community/approveAllAwaitingTopics",
    method: constants.post
  },
  "communityApproveAllSpamTopics": {
    url: "community/approveAllSpamTopics",
    method: constants.post
  },
  "communityApproveAllAwaitingComments": {
    url: "community/approveAllAwaitingComments",
    method: constants.post
  },
  "communityApproveAllSpamComments": {
    url: "community/approveAllSpamComments",
    method: constants.post
  },
  "communityTrashAllAwaitingTopics": {
    url: "community/trashAllAwaitingTopics",
    method: constants.post
  },
  "communityTrashAllSpamTopics": {
    url: "community/trashAllSpamTopics",
    method: constants.post
  },
  "communityTrashAllAwaitingComments": {
    url: "community/trashAllAwaitingComments",
    method: constants.post
  },
  "communityTrashAllSpamComments": {
    url: "community/trashAllSpamComments",
    method: constants.post
  },
  "communityUnModerateTopics": {
    url: "communityTopics/unmoderate",
    method: constants.post
  },
  "communityTopicsApprove": {
    url: "communityTopics/approve",
    method: constants.post
  },
  "communityCommentsApprove": {
    url: "communityComments/approve",
    method: constants.post
  },
  "communityTopicsRestore": {
    url: "communityTopics/restore",
    method: constants.post
  },
  "communityTopicsMoveToTrash": {
    url: "communityTopics/moveToTrash",
    method: constants.post
  },
  "communityTopicsDelete": {
    url: "communityTopics",
    method: constants.deleteIt
  },
  "communityCommentsRestore": {
    url: "communityComments/restore",
    method: constants.post
  },
  "communityCommentsMoveToTrash": {
    url: "communityComments/moveToTrash",
    method: constants.post
  },
  "communityCommentsDelete": {
    url: "communityComments",
    method: constants.deleteIt
  },
  "communityModeratedUsers": {
    url: "communityModeratedUsers",
    method: constants.get
  },
  "communityTopic": {
    url: "communityTopics/:id",
    method: constants.get
  },
  "communityTopicByPermalink": {
    url: "communityTopicByPermalink",
    method: constants.get
  },
  "communityUpdateTopic": {
    url: "communityTopics/:id",
    method: constants.patch
  },
  "communityTopicComments": {
    url: "communityTopics/:id/comments",
    method: constants.get
  },
  "communityComments.create": {
    url: "communityTopics/:id/comments",
    method: constants.post
  },
  "communityReply.create": {
    url: "communityTopics/:id/comments/:commentId/replies",
    method: constants.post
  },
  "communityUpdateComment": {
    url: "communityTopics/:id/comments/:commentId",
    method: constants.patch
  },
  "communityUpdateReply": {
    url: "communityTopics/:id/comments/:commentId/replies/:replyId",
    method: constants.patch
  },
  "communityCommentList": {
    url: "communityTopics/:id/comments",
    method: constants.post
  },
  "communityGetSingleComment": {
    url: "communityTopics/:id/comments/:commentId",
    method: constants.get
  },
  "communityDeleteComment": {
    url: "communityTopics/:id/comments/:commentId/moveToTrash",
    method: constants.deleteIt
  },
  "communityDeleteReply": {
    url: "communityTopics/:id/comments/:commentId/replies/:replyId/moveToTrash",
    method: constants.deleteIt
  },
  "communityAddAttachement": {
    url: "communityAttachments",
    method: constants.post
  },
  "communityGetTopicAttachment": {
    url: "communityTopics/:id/attachments/:attachementId/content",
    method: constants.get
  },
  "communityGetCommentAttachment": {
    url: "communityTopics/:id/comments/:commentId/attachments/:attachmentId/content",
    method: constants.get
  },
  "communityGetReplyAttachment": {
    url: "communityTopics/:id/replies/:replyId/attachments/:attachmentId/content",
    method: constants.get
  },
  "communityGetTicketAssociated": {
    url: "communityTopics/:id/ticket",
    method: constants.get
  },
  "communityTopicMarkSpam": {
    url: "communityTopics/:id/markSpam",
    method: constants.post
  },
  "communityMultipleTopicMarkSpam": {
    url: "community/markAllTopicsAsSpam",
    method: constants.post
  },
  "communityCommentMarkSpam": {
    url: "communityTopics/:id/comments/:commentId/markSpam",
    method: constants.post
  },
  "communityMultipleCommentMarkSpam": {
    url: "community/markAllCommentsAsSpam",
    method: constants.post
  },
  "communityLockTopic": {
    url: "communityTopics/:id/lock",
    method: constants.post
  },
  "communityUnlockTopic": {
    url: "communityTopics/:id/unlock",
    method: constants.post
  },
  "communityTopicLike": {
    url: "communityTopics/:id/like",
    method: constants.post
  },
  "communityTopicUnLike": {
    url: "communityTopics/:id/unlike",
    method: constants.post
  },
  "communityFollowTopic": {
    url: "communityTopics/:id/follow",
    method: constants.post
  },
  "communityUnFollowTopic": {
    url: "communityTopics/:id/unfollow",
    method: constants.post
  },
  "communityModerateTopic": {
    url: "communityTopics/:id/moderate",
    method: constants.post
  },
  "communityUnModerateTopic": {
    url: "communityTopics/:id/unmoderate",
    method: constants.post
  },
  "communityTrashTopic": {
    url: "communityTopics/:id/moveToTrash",
    method: constants.post
  },
  "communityMoveTopic": {
    url: "communityTopics/:id/move",
    method: constants.post
  },
  "communityAssociateTags": {
    url: "communityTopics/:id/associateTags",
    method: constants.post
  },
  "communityDeleteTags": {
    url: "communityTopics/:id/dissociateTags",
    method: constants.post
  },
  "communityTopicFollowersList": {
    url: "communityTopics/:id/followers",
    method: constants.get
  },
  "communityTopicParticipantsList": {
    url: "communityTopics/:id/participants",
    method: constants.get
  },
  "allCommunityCategories": {
    url: "allCommunityCategory",
    method: constants.get
  },
  "topicTypeTrend": {
    url: "community/topicTypeTrend",
    method: constants.get
  },
  "uniqueUsersParticipationTrend": {
    url: "community/uniqueUsersParticipationTrend",
    method: constants.get
  },
  "forums.sort": {
    url: "communityCategory/:id/sort",
    method: constants.post
  },
  "category.create": {
    url: "communityCategory",
    method: constants.post
  },
  "category.update": {
    url: "communityCategory/:id",
    method: constants.patch
  },
  "forum.create": {
    url: "communityCategory",
    method: constants.post
  },
  "category.get": {
    url: "communityCategory/:id",
    method: constants.get
  },
  "category.lock": {
    url: "communityCategory/:id/lock",
    method: constants.post
  },
  "category.enable": {
    url: "communityCategory/:id/enable",
    method: constants.post
  },
  "category.disable": {
    url: "communityCategory/:id/disable",
    method: constants.post
  },
  "categories.sort": {
    url: "communityCategory/sort",
    method: constants.post
  },
  "category.delete": {
    url: "communityCategory/:id",
    method: constants.deleteIt
  },
  "category.move": {
    url: "communityCategory/:id/move",
    method: constants.post
  },
  "communityUsersUnmoderate": {
    url: "communityUsers/unmoderate",
    method: constants.post
  },
  "topicType": {
    url: "communityTopicTypes",
    method: constants.get
  },
  "user": {
    url: "communityUsers/:id",
    method: constants.get
  },
  "user.stats": {
    url: "communityUsers/:id/stats",
    method: constants.get
  },
  "user.updateModeration": {
    url: "communityUsers/:id",
    method: constants.patch
  },
  "user.follow": {
    url: "communityUsers/:id/follow",
    method: constants.post
  },
  "user.unfollow": {
    url: "communityUsers/:id/unfollow",
    method: constants.post
  },
  "user.updateBlocking": {
    url: "users/:id",
    method: constants.patch
  },
  "user.topics.moveToTrash": {
    url: "communityUsers/:id/topics/moveToTrash",
    method: constants.post
  },
  "user.comments.moveToTrash": {
    url: "communityUsers/:id/comments/moveToTrash",
    method: constants.post
  },
  "category.add.logo": {
    url: "communityCategoryLogo",
    method: constants.post
  },
  "category.get.logo": {
    url: "communityCategory/:categoryId/logo/:logoId",
    method: constants.get
  },
  "community.licenseInfo": {
    url: "community/licenseInfo",
    method: constants.get
  },
  "communityMyDraftedTopics": {
    url: "communityMyDraftedTopics",
    method: constants.get
  },
  "searchTags": {
    url: "communityTags",
    method: constants.get
  },
  "mentions": {
    url: "mentions",
    method: constants.get
  },
  "communityTopicPermalink": {
    url: "communityTopics/:topicId/permalinks",
    method: constants.get
  },
  "communityUpdateTopicPermalink": {
    url: "communityTopics/:topicId/permalinks",
    method: constants.patch
  },
  "communityInitPermissions": {
    url: "communityInitPermissions",
    method: constants.get
  },
  "communityTopicsSearch": {
    url: "communityTopics/search",
    method: constants.get
  }
};

==> js-api-creator-1.0.22.tgz: package/es/modules/community.js <==
import { constants } from '@zohodesk/js-api-creator';
export default {
  "communityCategory": {
    url: "communityCategory",
    method: constants.get
  },
  "communityCategory.follow": {
    url: "communityCategory/:id/follow",
    method: constants.post
  },
  "communityCategory.unfollow": {
    url: "communityCategory/:id/unfollow",
    method: constants.post
  },
  "communityCategory.followers": {
    url: "communityCategory/:id/followers",
    method: constants.get
  },
  "communityAddTopic": {
    url: "communityTopics",
    method: constants.post
  },
  "communityDraftTopic": {
    url: "communityTopics/saveDraft",
    method: constants.post
  },
  "communityUpdateDraft": {
    url: "communityTopics/:id/updateDraft",
    method: constants.put
  },
  "communityPublishDraft": {
    url: "communityTopics/:id/publishDraft",
    method: constants.post
  },
  "communityDeleteDraft": {
    url: "communityTopics/:id/deleteDraft",
    method: constants.deleteIt
  },
  "communityTopics": {
    url: "communityTopics",
    method: constants.get
  },
  "communityTopContributors": {
    url: "community/topContributors",
    method: constants.get
  },
  "communityModerationTopics": {
    url: "communityModeration/topics",
    method: constants.get
  },
  "communityModerationComments": {
    url: "communityModeration/comments",
    method: constants.get
  },
  "communityModerationStats": {
    url: "communityModeration/counts",
    method: constants.get
  },
  "communityModeratedTopics": {
    url: "communityModeratedTopics",
    method: constants.get
  },
  "communityApproveAllAwaitingTopics": {
    url: "community/approveAllAwaitingTopics",
    method: constants.post
  },
  "communityApproveAllSpamTopics": {
    url: "community/approveAllSpamTopics",
    method: constants.post
  },
  "communityApproveAllAwaitingComments": {
    url: "community/approveAllAwaitingComments",
    method: constants.post
  },
  "communityApproveAllSpamComments": {
    url: "community/approveAllSpamComments",
    method: constants.post
  },
  "communityTrashAllAwaitingTopics": {
    url: "community/trashAllAwaitingTopics",
    method: constants.post
  },
  "communityTrashAllSpamTopics": {
    url: "community/trashAllSpamTopics",
    method: constants.post
  },
  "communityTrashAllAwaitingComments": {
    url: "community/trashAllAwaitingComments",
    method: constants.post
  },
  "communityTrashAllSpamComments": {
    url: "community/trashAllSpamComments",
    method: constants.post
  },
  "communityUnModerateTopics": {
    url: "communityTopics/unmoderate",
    method: constants.post
  },
  "communityTopicAddAsTicket": {
    url: "communityTopics/:id/addAsTicket",
    method: constants.post
  },
  "communityTopicsApprove": {
    url: "communityTopics/approve",
    method: constants.post
  },
  "communityCommentsApprove": {
    url: "communityComments/approve",
    method: constants.post
  },
  "communityTopicsRestore": {
    url: "communityTopics/restore",
    method: constants.post
  },
  "communityTopicsMoveToTrash": {
    url: "communityTopics/moveToTrash",
    method: constants.post
  },
  "communityTopicsDelete": {
    url: "communityTopics",
    method: constants.deleteIt
  },
  "communityCommentsRestore": {
    url: "communityComments/restore",
    method: constants.post
  },
  "communityCommentsMoveToTrash": {
    url: "communityComments/moveToTrash",
    method: constants.post
  },
  "communityCommentsDelete": {
    url: "communityComments",
    method: constants.deleteIt
  },
  "communityModeratedUsers": {
    url: "communityModeratedUsers",
    method: constants.get
  },
  "communityTopic": {
    url: "communityTopics/:id",
    method: constants.get
  },
  "communityTopicByPermalink": {
    url: "communityTopicByPermalink",
    method: constants.get
  },
  "communityUpdateTopic": {
    url: "communityTopics/:id",
    method: constants.patch
  },
  "communityTopicComments": {
    url: "communityTopics/:id/comments",
    method: constants.get
  },
  "communityComments.create": {
    url: "communityTopics/:id/comments",
    method: constants.post
  },
  "communityReply.create": {
    url: "communityTopics/:id/comments/:commentId/replies",
    method: constants.post
  },
  "communityUpdateComment": {
    url: "communityTopics/:id/comments/:commentId",
    method: constants.patch
  },
  "communityUpdateReply": {
    url: "communityTopics/:id/comments/:commentId/replies/:replyId",
    method: constants.patch
  },
  "communityCommentList": {
    url: "communityTopics/:id/comments",
    method: constants.post
  },
  "communityGetSingleComment": {
    url: "communityTopics/:id/comments/:commentId",
    method: constants.get
  },
  "communityDeleteComment": {
    url: "communityTopics/:id/comments/:commentId/moveToTrash",
    method: constants.post
  },
  "communityDeleteReply": {
    url: "communityTopics/:id/comments/:commentId/replies/:replyId/moveToTrash",
    method: constants.post
  },
  "communityAddAttachement": {
    url: "communityAttachments",
    method: constants.post
  },
  "communityGetTopicAttachment": {
    url: "communityTopics/:id/attachments/:attachementId/content",
    method: constants.get
  },
  "communityGetCommentAttachment": {
    url: "communityTopics/:id/comments/:commentId/attachments/:attachmentId/content",
    method: constants.get
  },
  "communityGetReplyAttachment": {
    url: "communityTopics/:id/replies/:replyId/attachments/:attachmentId/content",
    method: constants.get
  },
  "communityGetTicketAssociated": {
    url: "communityTopics/:id/ticket",
    method: constants.get
  },
  "communityTopicMarkSpam": {
    url: "communityTopics/:id/markSpam",
    method: constants.post
  },
  "communityMultipleTopicMarkSpam": {
    url: "community/markAllTopicsAsSpam",
    method: constants.post
  },
  "communityCommentMarkSpam": {
    url: "communityTopics/:id/comments/:commentId/markSpam",
    method: constants.post
  },
  "communityMultipleCommentMarkSpam": {
    url: "community/markAllCommentsAsSpam",
    method: constants.post
  },
  "communityLockTopic": {
    url: "communityTopics/:id/lock",
    method: constants.post
  },
  "communityUnlockTopic": {
    url: "communityTopics/:id/unlock",
    method: constants.post
  },
  "communityTopicLike": {
    url: "communityTopics/:id/like",
    method: constants.post
  },
  "communityTopicUnLike": {
    url: "communityTopics/:id/unlike",
    method: constants.post
  },
  "communityFollowTopic": {
    url: "communityTopics/:id/follow",
    method: constants.post
  },
  "communityUnFollowTopic": {
    url: "communityTopics/:id/unfollow",
    method: constants.post
  },
  "communityModerateTopic": {
    url: "communityTopics/:id/moderate",
    method: constants.post
  },
  "communityUnModerateTopic": {
    url: "communityTopics/:id/unmoderate",
    method: constants.post
  },
  "communityTrashTopic": {
    url: "communityTopics/:id/moveToTrash",
    method: constants.post
  },
  "communityMoveTopic": {
    url: "communityTopics/:id/move",
    method: constants.post
  },
  "communityAssociateTags": {
    url: "communityTopics/:id/associateTags",
    method: constants.post
  },
  "communityDeleteTags": {
    url: "communityTopics/:id/dissociateTags",
    method: constants.post
  },
  "communityTopicFollowers": {
    url: "communityTopics/:id/followers",
    method: constants.get
  },
  "communityTopicParticipants": {
    url: "communityTopics/:id/participants",
    method: constants.get
  },
  "communityTopicVoters": {
    url: "communityTopics/:id/voters",
    method: constants.get
  },
  "communityTopicVotersTrend": {
    url: "communityTopics/:id/voters/trend",
    method: constants.get
  },
  "allCommunityCategories": {
    url: "allCommunityCategory",
    method: constants.get
  },
  "topicTypeTrend": {
    url: "community/topicTypeTrend",
    method: constants.get
  },
  "uniqueUsersParticipationTrend": {
    url: "community/uniqueUsersParticipationTrend",
    method: constants.get
  },
  "forums.sort": {
    url: "communityCategory/:id/sort",
    method: constants.post
  },
  "category.create": {
    url: "communityCategory",
    method: constants.post
  },
  "category.update": {
    url: "communityCategory/:id",
    method: constants.patch
  },
  "forum.create": {
    url: "communityCategory",
    method: constants.post
  },
  "category.get": {
    url: "communityCategory/:id",
    method: constants.get
  },
  "category.lock": {
    url: "communityCategory/:id/lock",
    method: constants.post
  },
  "category.enable": {
    url: "communityCategory/:id/enable",
    method: constants.post
  },
  "category.disable": {
    url: "communityCategory/:id/disable",
    method: constants.post
  },
  "categories.sort": {
    url: "communityCategory/sort",
    method: constants.post
  },
  "category.delete": {
    url: "communityCategory/:id",
    method: constants.deleteIt
  },
  "category.move": {
    url: "communityCategory/:id/move",
    method: constants.post
  },
  "communityUsersUnmoderate": {
    url: "communityUsers/unmoderate",
    method: constants.post
  },
  "topicType": {
    url: "communityTopicTypes",
    method: constants.get
  },
  "user": {
    url: "communityUsers/:id",
    method: constants.get
  },
  "user.stats": {
    url: "communityUsers/:id/stats",
    method: constants.get
  },
  "user.updateModeration": {
    url: "communityUsers/:id",
    method: constants.patch
  },
  "user.follow": {
    url: "communityUsers/:id/follow",
    method: constants.post
  },
  "user.unfollow": {
    url: "communityUsers/:id/unfollow",
    method: constants.post
  },
  "user.updateBlocking": {
    url: "users/:id",
    method: constants.patch
  },
  "user.topics.moveToTrash": {
    url: "communityUsers/:id/topics/moveToTrash",
    method: constants.post
  },
  "user.comments.moveToTrash": {
    url: "communityUsers/:id/comments/moveToTrash",
    method: constants.post
  },
  "category.add.logo": {
    url: "communityCategoryLogo",
    method: constants.post
  },
  "category.get.logo": {
    url: "communityCategory/:categoryId/logo/:logoId",
    method: constants.get
  },
  "community.licenseInfo": {
    url: "community/licenseInfo",
    method: constants.get
  },
  "communityMyDraftedTopics": {
    url: "communityMyDraftedTopics",
    method: constants.get
  },
  "searchTags": {
    url: "communityTags",
    method: constants.get
  },
  "mentions": {
    url: "mentions",
    method: constants.get
  },
  "communityTopicPermalink": {
    url: "communityTopics/:topicId/permalinks",
    method: constants.get
  },
  "communityUpdateTopicPermalink": {
    url: "communityTopics/:topicId/permalinks",
    method: constants.patch
  },
  "communityInitPermissions": {
    url: "communityInitPermissions",
    method: constants.get
  },
  "communityTopicsSearch": {
    url: "communityTopics/search",
    method: constants.get
  }
};
